@@ -1,11 +1,9 @@
 from contextlib import contextmanager
 from timeit import default_timer
 from sherlockpipe.sherlock import Sherlock
-from sherlockpipe.objectinfo.InputObjectInfo import InputObjectInfo
-from sherlockpipe.objectinfo.MissionFfiCoordsObjectInfo import MissionFfiCoordsObjectInfo
-from sherlockpipe.objectinfo.MissionFfiIdObjectInfo import MissionFfiIdObjectInfo
-from sherlockpipe.objectinfo.MissionInputObjectInfo import MissionInputObjectInfo
-from sherlockpipe.objectinfo.MissionObjectInfo import MissionObjectInfo
+from lcbuilder.objectinfo.MissionObjectInfo import MissionObjectInfo
+
+from sherlockpipe.sherlock_target import SherlockTarget
 
 
 @contextmanager
@@ -20,7 +18,7 @@ def elapsed_timer():
 with elapsed_timer() as elapsed:
     # We will use only one mission object and will enable the automatic high RMS masking. We will set a RMS threshold
     # of 2 times the median with a binning of 3 hours.
-    sherlock = Sherlock([MissionObjectInfo("TIC 181804752", 'all')])\
-        .setup_detrend(initial_rms_mask=True, initial_rms_threshold=2.5, initial_rms_bin_hours=3)\
+    sherlock = Sherlock([SherlockTarget(MissionObjectInfo("TIC 181804752", 'all'), high_rms_enabled=True,
+                                        high_rms_threshold=2.5, high_rms_bin_hours=3)])\
         .run()
     print("Analysis took " + elapsed() + "s")
