@@ -6,9 +6,9 @@ rm -r .tox
 rm -r .pytest_cache
 rm -r build
 set -e
-#tox -r > tests.log
-#tests_results=$(cat tests.log | grep "congratulations")
-#if ! [[ -z ${tests_results} ]]; then
+tox -r > tests.log
+tests_results=$(cat tests.log | grep "congratulations")
+if ! [[ -z ${tests_results} ]]; then
   git_tag=$1
   sed -i '6s/.*/version = "'${git_tag}'"/' setup.py
   sed -i '1s/.*/__version__ = "'${git_tag}'"/' sherlockpipe/__init__.py
@@ -31,9 +31,9 @@ set -e
   sudo docker push sherlockpipe/sherlockpipe:${git_tag}
   sudo docker images prune -all
   rm tests.log
-#else
-#  echo "TESTS FAILED. See tests.log"
-#fi
+else
+  echo "TESTS FAILED. See tests.log"
+fi
 rm dist* -r
 rm -r .tox
 rm -r .pytest_cache
