@@ -6,8 +6,8 @@ cpus = 1
 first_negative_sector = 1
 training_data_dir = "/mnt/DATA-2/training_data/"
 cache_dir = "/home/martin/"
-#ml_training_set_preparer = MlTrainingSetPreparer(training_data_dir, cache_dir)
-#ml_training_set_preparer.prepare_positive_training_dataset(cpus)
+ml_training_set_preparer = MlTrainingSetPreparer(training_data_dir, cache_dir)
+ml_training_set_preparer.prepare_positive_training_dataset(cpus)
 #ml_training_set_preparer.prepare_false_positive_training_dataset(cpus)
 #ml_training_set_preparer.prepare_negative_training_dataset(first_negative_sector, cpus)
 #MLSingleTransitsClassifier().load_candidate_single_transits(traid ning_data_dir, "tp")
