@@ -237,29 +237,6 @@ class MlTrainingSetPreparer:
         try:
             lcbuild_long = \
                 mission_ffi_lightcurve_builder.build(MissionFfiIdObjectInfo(tic_id, 'all'), target_dir, self.cache_dir)
-            star_df = pd.DataFrame(columns=['obj_id', 'ra', 'dec', 'R_star', 'R_star_lerr', 'R_star_uerr', 'M_star',
-                                                'M_star_lerr', 'M_star_uerr', 'Teff_star', 'Teff_star_lerr',
-                                                'Teff_star_uerr', 'ld_a', 'ld_b'])
-            ld_a = lcbuild_long.star_info.ld_coefficients[0] if lcbuild_long.star_info.ld_coefficients is not None else None
-            ld_b = lcbuild_long.star_info.ld_coefficients[1] if lcbuild_long.star_info.ld_coefficients is not None else None
-            star_df = star_df.append(
-                {'obj_id': tic_id, 'ra': lcbuild_long.star_info.ra, 'dec': lcbuild_long.star_info.dec,
-                 'R_star': lcbuild_long.star_info.radius,
-                 'R_star_lerr': lcbuild_long.star_info.radius - lcbuild_long.star_info.radius_min,
-                 'R_star_uerr': lcbuild_long.star_info.radius_max - lcbuild_long.star_info.radius,
-                 'M_star': lcbuild_long.star_info.mass, 'M_star_lerr': lcbuild_long.star_info.mass - lcbuild_long.star_info.mass_min,
-                 'M_star_uerr': lcbuild_long.star_info.mass_max - lcbuild_long.star_info.mass,
-                 'Teff_star': lcbuild_long.star_info.teff, 'Teff_star_lerr': 200, 'Teff_star_uerr': 200,
-                 'logg': lcbuild_long.star_info.logg, 'logg_err': lcbuild_long.star_info.logg_err,
-                 'ld_a': ld_a, 'ld_b': ld_b,
-                 'feh': lcbuild_long.star_info.feh,
-                 'feh_err': lcbuild_long.star_info.feh_err, 'v': lcbuild_long.star_info.v, 'v_err': lcbuild_long.star_info.v_err,
-                 'j': lcbuild_long.star_info.j, 'j_err': lcbuild_long.star_info.j_err,
-                 'k': lcbuild_long.star_info.k, 'k_err': lcbuild_long.star_info.k_err,
-                 'h': lcbuild_long.star_info.h, 'h_err': lcbuild_long.star_info.h_err,
-                 'kp': lcbuild_long.star_info.kp},
-                ignore_index=True)
-            star_df.to_csv(target_dir + "params_star.csv", index=False)
             sectors = lcbuild_long.sectors
             lc_long = lcbuild_long.lc
             lc_data_long = self.store_lc_data(lcbuild_long.lc_data, target_dir + "time_series_long.csv")
@@ -271,29 +248,66 @@ class MlTrainingSetPreparer:
             periodogram_df.to_csv(target_dir + "periodogram_long.csv")
             logging.info("Downloading neighbour stars for " + prepare_tic_input.tic)
             #TODO get neighbours light curves stars = self.download_neighbours(prepare_tic_input.tic, sectors)
-            logging.info("Classifying candidate points for " + prepare_tic_input.tic)
-            if prepare_tic_input.label == "TP":
-                target_ois = prepare_tic_input.target_ois[
-                    (prepare_tic_input.target_ois["Disposition"] == "CP") |
-                    (prepare_tic_input.target_ois["Disposition"] == "KP")]
-            elif prepare_tic_input.label == "FP":
-                target_ois = prepare_tic_input.target_ois[
-                    (prepare_tic_input.target_ois["Disposition"] == "FP") |
-                    (prepare_tic_input.target_ois["Disposition"] == "FA")]
-            else:
-                target_ois = prepare_tic_input.target_ois[
-                    (prepare_tic_input.target_ois["Disposition"] == "FAKE")]
-            target_ois_df = pd.DataFrame(
-                columns=['id', 'name', 'period', 'period_err', 't0', 'to_err', 'depth', 'depth_err', 'duration',
-                         'duration_err', 'score'])
+            # TODO store folded light curves -with local and global views-(masking previous candidates?)
+        except Exception as e:
+            failed_target = tic_id
+            logging.exception(e)
+        try:
+            star_df = pd.DataFrame(columns=['obj_id', 'ra', 'dec', 'R_star', 'R_star_lerr', 'R_star_uerr', 'M_star',
+                                            'M_star_lerr', 'M_star_uerr', 'Teff_star', 'Teff_star_lerr',
+                                            'Teff_star_uerr', 'ld_a', 'ld_b'])
+            ld_a = lcbuild_long.star_info.ld_coefficients[
+                0] if lcbuild_long.star_info.ld_coefficients is not None else None
+            ld_b = lcbuild_long.star_info.ld_coefficients[
+                1] if lcbuild_long.star_info.ld_coefficients is not None else None
+            star_df = star_df.append(
+                {'obj_id': tic_id, 'ra': lcbuild_long.star_info.ra, 'dec': lcbuild_long.star_info.dec,
+                 'R_star': lcbuild_long.star_info.radius,
+                 'R_star_lerr': lcbuild_long.star_info.radius - lcbuild_long.star_info.radius_min,
+                 'R_star_uerr': lcbuild_long.star_info.radius_max - lcbuild_long.star_info.radius,
+                 'M_star': lcbuild_long.star_info.mass,
+                 'M_star_lerr': lcbuild_long.star_info.mass - lcbuild_long.star_info.mass_min,
+                 'M_star_uerr': lcbuild_long.star_info.mass_max - lcbuild_long.star_info.mass,
+                 'Teff_star': lcbuild_long.star_info.teff, 'Teff_star_lerr': 200, 'Teff_star_uerr': 200,
+                 'logg': lcbuild_long.star_info.logg, 'logg_err': lcbuild_long.star_info.logg_err,
+                 'ld_a': ld_a, 'ld_b': ld_b,
+                 'feh': lcbuild_long.star_info.feh,
+                 'feh_err': lcbuild_long.star_info.feh_err, 'v': lcbuild_long.star_info.v,
+                 'v_err': lcbuild_long.star_info.v_err,
+                 'j': lcbuild_long.star_info.j, 'j_err': lcbuild_long.star_info.j_err,
+                 'k': lcbuild_long.star_info.k, 'k_err': lcbuild_long.star_info.k_err,
+                 'h': lcbuild_long.star_info.h, 'h_err': lcbuild_long.star_info.h_err,
+                 'kp': lcbuild_long.star_info.kp},
+                ignore_index=True)
+            star_df.to_csv(target_dir + "params_star.csv", index=False)
+        except Exception as e:
+            logging.warning("Failed star df preparation for TIC " + str(prepare_tic_input.tic))
+        try:
             if lc_data_short is not None:
                 tags_series_short = np.full(len(lc_data_short.time), "BL")
-            tags_series_long = np.full(len(lc_data_long.time), "BL")
+            if lc_data_long is not None:
+                tags_series_long = np.full(len(lc_data_long.time), "BL")
+            target_ois_df = pd.DataFrame(
+                     columns=['id', 'name', 'period', 'period_err', 't0', 'to_err', 'depth', 'depth_err', 'duration',
+                     'duration_err', 'score'])
             if prepare_tic_input.label is not None:
+                logging.info("Classifying candidate points for " + prepare_tic_input.tic)
+                if prepare_tic_input.label == "TP":
+                    target_ois = prepare_tic_input.target_ois[
+                        (prepare_tic_input.target_ois["Disposition"] == "CP") |
+                        (prepare_tic_input.target_ois["Disposition"] == "KP")]
+                elif prepare_tic_input.label == "FP":
+                    target_ois = prepare_tic_input.target_ois[
+                        (prepare_tic_input.target_ois["Disposition"] == "FP") |
+                        (prepare_tic_input.target_ois["Disposition"] == "FA")]
+                else:
+                    target_ois = prepare_tic_input.target_ois[
+                        (prepare_tic_input.target_ois["Disposition"] == "FAKE")]
                 for index, row in target_ois.iterrows():
                     if row["OI"] not in prepare_tic_input.excluded_ois:
-                        logging.info("Classifying candidate points with OI %s, period %s, t0 %s and duration %s for " + prepare_tic_input.tic,
-                                     row["OI"], row["Period (days)"], row["Epoch (BJD)"], row["Duration (hours)"])
+                        logging.info(
+                            "Classifying candidate points with OI %s, period %s, t0 %s and duration %s for " + prepare_tic_input.tic,
+                            row["OI"], row["Period (days)"], row["Epoch (BJD)"], row["Duration (hours)"])
                         target_ois_df = target_ois_df.append(
                             {"id": row["Object Id"], "name": row["OI"], "period": row["Period (days)"],
                              "period_err": row["Period (days) err"], "t0": row["Epoch (BJD)"] - 2457000.0,
@@ -305,9 +319,11 @@ class MlTrainingSetPreparer:
                             mask_short = tls.transit_mask(lc_data_short["time"].to_numpy(), row["Period (days)"],
                                                           row["Duration (hours)"] / 24, row["Epoch (BJD)"] - 2457000.0)
                             tags_series_short[mask_short] = prepare_tic_input.label
-                        mask_long = tls.transit_mask(lc_data_long["time"].to_numpy(), row["Period (days)"], row["Duration (hours)"] / 24,
+                        if lc_long is not None:
+                            mask_long = tls.transit_mask(lc_data_long["time"].to_numpy(), row["Period (days)"],
+                                                     row["Duration (hours)"] / 24,
                                                      row["Epoch (BJD)"] - 2457000.0)
-                        tags_series_long[mask_long] = prepare_tic_input.label
+                            tags_series_long[mask_long] = prepare_tic_input.label
                 for index, row in prepare_tic_input.target_additional_ois_df.iterrows():
                     if row["OI"] not in prepare_tic_input.excluded_ois:
                         target_ois_df = target_ois_df.append(
@@ -321,19 +337,20 @@ class MlTrainingSetPreparer:
                             mask_short = tls.transit_mask(lc_data_short["time"].to_numpy(), row["Period (days)"],
                                                           row["Duration (hours)"] / 24, row["Epoch (BJD)"] - 2457000.0)
                             tags_series_short[mask_short] = prepare_tic_input.label
-                        mask_long = tls.transit_mask(lc_data_long["time"].to_numpy(), row["Period (days)"], row["Duration (hours)"] / 24,
-                                                     row["Epoch (BJD)"] - 2457000.0)
-                        tags_series_long[mask_long] = prepare_tic_input.label
+                        if lc_long is not None:
+                            mask_long = tls.transit_mask(lc_data_long["time"].to_numpy(), row["Period (days)"],
+                                                         row["Duration (hours)"] / 24,
+                                                         row["Epoch (BJD)"] - 2457000.0)
+                            tags_series_long[mask_long] = prepare_tic_input.label
             target_ois_df.to_csv(target_dir + "/ois.csv")
             if lc_data_short is not None:
                 lc_data_short["tag"] = tags_series_short
                 lc_data_short.to_csv(target_dir + "time_series_short.csv")
-            lc_data_long["tag"] = tags_series_long
-            lc_data_long.to_csv(target_dir + "time_series_long.csv")
-            # TODO store folded light curves -with local and global views-(masking previous candidates?)
+            if lc_data_long is not None:
+                lc_data_long["tag"] = tags_series_long
+                lc_data_long.to_csv(target_dir + "time_series_long.csv")
         except Exception as e:
-            failed_target = tic_id
-            logging.exception(e)
+            logging.error("Cannot generate ois.csv for " + str(prepare_tic_input.tic))
         return failed_target
 
     def prepare_positive_tic(self, prepare_tic_input):
@@ -496,7 +513,7 @@ class MlTrainingSetPreparer:
                     os.path.exists(src + "/time_series_" + mode + ".csv"):
                 ois_df = pd.read_csv(src + "/ois.csv")
                 for index, oi_row in ois_df.iterrows():
-                    dst_index = dst + "_" + str(index)
+                    dst_index = dst + str(index)
                     os.symlink(src, dst_index)
         logging.info("Flattening negative dir %s", negative_dir)
         for file in os.listdir(false_positive_dir):
@@ -506,7 +523,7 @@ class MlTrainingSetPreparer:
                     os.path.exists(src + "/time_series_" + mode + ".csv"):
                 ois_df = pd.read_csv(src + "/ois.csv")
                 for index, oi_row in ois_df.iterrows():
-                    dst_index = dst + "_" + str(index)
+                    dst_index = dst + str(index)
                     os.symlink(src, dst_index)
         logging.info("Flattening false positive dir %s", false_positive_dir)
         np.random.seed(0)
