@@ -241,8 +241,20 @@ class Sherlock:
             logging.info('SEARCH RUNS with period grid: [%.2f - %.2f] and length %.0f', np.min(period_grid),
                          np.max(period_grid), len(period_grid))
             logging.info('================================================')
-            lcs, wl = self.__detrend(sherlock_target, time, flux, lc_build.star_info)
+            lcs, wl = self.__detrend(sherlock_target, time, flux, flux_err,
+                                     lc_build.star_info)
             lcs = np.concatenate(([flux], lcs), axis=0)
+            object_info = sherlock_target.object_info
+            object_dir = self.__init_object_dir(object_info.sherlock_id())
+            i = 0
+            for lc in lcs:
+                lc_df = pandas.DataFrame(columns=['#time', 'flux', 'flux_err'])
+                args = np.argwhere(~np.isnan(lc)).flatten()
+                lc_df['#time'] = time[args]
+                lc_df['flux'] = lc[args]
+                lc_df['flux_err'] = flux_err[args]
+                lc_df.to_csv(object_dir + "/lc_" + str(i) + ".csv", index=False)
+                i = i + 1
             wl = np.concatenate(([0], wl), axis=0)
             transits_stats_df = pandas.DataFrame(columns=['candidate', 't0', 'depth', 'depth_err'])
             while not self.explore and best_signal_score == 1 and id_run <= sherlock_target.max_runs:
@@ -276,12 +288,16 @@ class Sherlock:
                 object_report["duration"] = transit_results[signal_selection.curve_index].duration * 60 * 24
                 object_report["t0"] = transit_results[signal_selection.curve_index].t0
                 object_report["depth"] = transit_results[signal_selection.curve_index].depth
-                object_report['rp_rs'] = transit_results[signal_selection.curve_index].results.rp_rs
-                real_transit_args = np.argwhere(~np.isnan(transit_results[signal_selection.curve_index]
-                                                          .results.transit_depths))
-                object_report["transits"] = np.array(transit_results[signal_selection.curve_index]
-                                                          .results.transit_times)[real_transit_args.flatten()]
-                object_report["transits"] = ','.join(map(str, object_report["transits"]))
+                if transit_results[signal_selection.curve_index].results is not None:
+                    object_report['rp_rs'] = transit_results[signal_selection.curve_index].results.rp_rs
+                    real_transit_args = np.argwhere(~np.isnan(transit_results[signal_selection.curve_index]
+                                                              .results.transit_depths))
+                    object_report["transits"] = np.array(transit_results[signal_selection.curve_index]
+                                                         .results.transit_times)[real_transit_args.flatten()]
+                    object_report["transits"] = ','.join(map(str, object_report["transits"]))
+                else:
+                    object_report['rp_rs'] = 0
+                    object_report["transits"] = ""
                 object_report["sectors"] = ','.join(map(str, lc_build.sectors)) \
                     if lc_build.sectors is not None and len(lc_build.sectors) > 0 else None
                 object_report["ffi"] = isinstance(sherlock_target, MissionFfiIdObjectInfo) or \
@@ -495,8 +511,8 @@ class Sherlock:
             transit_duration = wotan.t14(R_s=lc_build.star_info.radius, M_s=lc_build.star_info.mass,
                                          P=sherlock_target.period_protect, small_planet=True)
             if sherlock_target.detrend_method == 'gp':
-                self.wl_min[sherlock_id] = 1
-                self.wl_max[sherlock_id] = 12
+                self.wl_min[sherlock_id] = 3 * transit_duration
+                self.wl_max[sherlock_id] = 20 * transit_duration
             else:
                 self.wl_min[sherlock_id] = 3 * transit_duration  # minimum transit duration
                 self.wl_max[sherlock_id] = 20 * transit_duration  # maximum transit duration
@@ -528,7 +544,7 @@ class Sherlock:
         logging.info(signal_selection.get_message())
         return transit_results, signal_selection
 
-    def __detrend(self, sherlock_target, time, lc, star_info):
+    def __detrend(self, sherlock_target, time, lc, flux_err, star_info):
         wl_min = self.wl_min[star_info.object_id]
         wl_max = self.wl_max[star_info.object_id]
         bins = len(time) * 2 / sherlock_target.bin_minutes
@@ -626,43 +642,33 @@ class Sherlock:
                      "SNR", "SDE", "FAP", "Border_score", "Matching OI", "Harmonic", "Planet radius (R_Earth)", "Rp/Rs",
                      "Semi-major axis", "Habitability Zone")
         transit_results = {}
-        run_dir = self.__init_object_run_dir(object_info.sherlock_id(), id_run)
-        lc_df = pandas.DataFrame(columns=['#time', 'flux', 'flux_err'])
-        args = np.argwhere(~np.isnan(lcs[0])).flatten()
-        lc_df['#time'] = time[args]
-        lc_df['flux'] = lcs[0][args]
-        lc_df['flux_err'] = flux_err[args]
-        lc_df.to_csv(run_dir + "/lc_0.csv", index=False)
-        transit_result = self.__adjust_transit(sherlock_target, time, lcs[0], star_info, transits_min_count,
-                                               transit_results, report, cadence, period_grid, detrend_source_period)
+        if not sherlock_target.ignore_original:
+            transit_result = self.__adjust_transit(sherlock_target, time, lcs[0], star_info, transits_min_count,
+                                                   transit_results, report, cadence, period_grid, detrend_source_period)
+            r_planet = self.__calculate_planet_radius(star_info, transit_result.depth)
+            rp_rs = transit_result.results.rp_rs
+            a, habitability_zone = self.habitability_calculator \
+                .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
+            oi = self.__find_matching_oi(object_info, transit_result.period)
+            logging.info('%-12s%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
+                         "PDCSAP_FLUX", transit_result.period,
+                         transit_result.per_err, transit_result.count, transit_result.depth,
+                         transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
+                         transit_result.fap, transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
+                         habitability_zone)
+            plot_title = 'Run ' + str(id_run) + 'PDCSAP_FLUX # P=' + \
+                         format(transit_result.period, '.2f') + 'd # T0=' + format(transit_result.t0, '.2f') + \
+                         ' # Depth=' + format(transit_result.depth, '.4f') + 'ppt # Dur=' + \
+                         format(transit_result.duration * 24 * 60, '.0f') + 'm # SNR:' + \
+                         str(format(transit_result.snr, '.2f')) + ' # SDE:' + str(format(transit_result.sde, '.2f')) + \
+                         ' # FAP:' + format(transit_result.fap, '.6f')
+            plot_file = 'Run_' + str(id_run) + '_PDCSAP-FLUX_' + str(star_info.object_id) + '.png'
+            self.__save_transit_plot(star_info.object_id, plot_title, plot_file, time, lcs[0], transit_result, cadence,
+                                     id_run)
+        else:
+            transit_result = TransitResult(None, 0, 0, 0, 0, [], [], 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, [], False)
         transit_results[0] = transit_result
-        r_planet = self.__calculate_planet_radius(star_info, transit_result.depth)
-        rp_rs = transit_result.results.rp_rs
-        a, habitability_zone = self.habitability_calculator \
-            .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
-        oi = self.__find_matching_oi(object_info, transit_result.period)
-        logging.info('%-12s%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
-                     "PDCSAP_FLUX", transit_result.period,
-                     transit_result.per_err, transit_result.count, transit_result.depth,
-                     transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
-                     transit_result.fap, transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
-                     habitability_zone)
-        plot_title = 'Run ' + str(id_run) + 'PDCSAP_FLUX # P=' + \
-                     format(transit_result.period, '.2f') + 'd # T0=' + format(transit_result.t0, '.2f') + \
-                     ' # Depth=' + format(transit_result.depth, '.4f') + 'ppt # Dur=' + \
-                     format(transit_result.duration * 24 * 60, '.0f') + 'm # SNR:' + \
-                     str(format(transit_result.snr, '.2f')) + ' # SDE:' + str(format(transit_result.sde, '.2f')) + \
-                     ' # FAP:' + format(transit_result.fap, '.6f')
-        plot_file = 'Run_' + str(id_run) + '_PDCSAP-FLUX_' + str(star_info.object_id) + '.png'
-        self.__save_transit_plot(star_info.object_id, plot_title, plot_file, time, lcs[0], transit_result, cadence,
-                                 id_run)
         for i in range(1, len(wl)):
-            lc_df = pandas.DataFrame(columns=['#time', 'flux', 'flux_err'])
-            args = np.argwhere(~np.isnan(lcs[i])).flatten()
-            lc_df['#time'] = time[args]
-            lc_df['flux'] = lcs[i][args]
-            lc_df['flux_err'] = flux_err[args]
-            lc_df.to_csv(run_dir + "/lc_" + str(i) + ".csv", index=False)
             transit_result = self.__adjust_transit(sherlock_target, time, lcs[i], star_info, transits_min_count,
                                                    transit_results, report, cadence, period_grid, detrend_source_period)
             transit_results[i] = transit_result
@@ -793,7 +799,7 @@ class Sherlock:
             if len(period_harmonic) > 0:
                 period_harmonic = scales[period_harmonic[0]]
                 return str(period_harmonic) + "*SOI" + str(key + 1)
-        period_scales = [round(tls_results.period / run_results[key].period, 2) for key in run_results]
+        period_scales = [round(tls_results.period / run_results[key].period, 2) if run_results[key].period > 0 else 0 for key in run_results]
         for key, period_scale in enumerate(period_scales):
             period_harmonic = np.array(np.argwhere(
                 (np.array(scales) > period_scale - 0.02) & (np.array(scales) < period_scale + 0.02))).flatten()
@@ -849,7 +855,9 @@ class Sherlock:
             bin_width = (bin_edges[1] - bin_edges[0])
             bin_centers = bin_edges[1:] - bin_width / 2
             bin_size = int(folded_plot_range * 2 / bins * transit_result.period * 24 * 60)
-            ax2.errorbar(bin_centers, bin_means, yerr=bin_stds / 2, xerr=bin_width / 2, marker='o', markersize=4,
+            bin_means_data_mask = np.isnan(bin_means)
+            ax2.errorbar(bin_centers[~bin_means_data_mask], bin_means[~bin_means_data_mask],
+                         yerr=bin_stds[~bin_means_data_mask] / 2, xerr=bin_width / 2, marker='o', markersize=4,
                          color='darkorange', alpha=1, linestyle='none', label='Bin size: ' + str(bin_size) + "m")
             ax2.legend(loc="upper right")
         ax3 = plt.gca()
